#ifndef CAMERA_H
#define CAMERA_H

#include <GL/glew.h>
#include <glm/glm.hpp>

#define PERSPECTIVE 0
#define ORTHOGRAPHIC 1
class CameraArcball
{
	public :
		CameraArcball();		//Constructor
		~CameraArcball();		//Destructor

	public :
		//An initialization from a center and a radius
		void initialize(int _width, int _height, glm::vec3 _center, float _radius);

		//Rotate camera arround one of axis
		void rotateX( float angle );
		void rotateY( float angle );
		//Translate camera along one of axis
		void translateX( float delta );
		void translateY( float delta );

		//Update view, projection matrix once interaction occured
		void update();

	public :
		glm::vec3 position;			//camera position
		glm::vec3 center;			//camera target

		int width;					//screen width
		int height;					//screen height
		float fov;					//field of view of the camera
		float nearPlane;			//near plane of the frustum
		float farPlane;				//far plane of the frustum

		glm::vec3 rotation;			//total rotation of the camera from origin
		glm::vec3 translation;		//total translation of the camera from origin

		float radius;				//radius of the sphere

		glm::mat4 view;				//view matrix
		glm::mat4 projection;		//projection matrix

		GLuint viewMatrixID;		//view matrix shader attribute ID
		GLuint projectionMatrixID;	//projection matrix shader attribute ID
};

#endif
