#ifndef GLWIDGET_H
#define GLWIDGET_H

#include <iostream>
#include <shader.hpp> // Help to load shaders from files
#include<meshLoader.h>
// Include GLEW : Always include it before glfw.h et gl.h :)
#include <GL/glew.h> // OpenGL Extension Wrangler Library : http://glew.sourceforge.net/ 
#include <GL/glfw.h> // Window, keyboard, mouse : http://www.glfw.org/
#include <glm/glm.hpp> // OpenGL Mathematics : www.http://glm.g-truc.net/0.9.5/index.html
#include <glm/gtc/type_ptr.hpp>
#include <camera.h>

class GLwidget
{
	public :
		GLwidget();
		~GLwidget();
		void renderShader();				//shader pipeline drawing
		void renderFix();					//fix pipeline drawing 
		void eventHandler();				//handle events (mouse, keyboard)
		void displayLoop();					//draw loop
		void init(const char* filename);	//init with a loading from a mesh file

	private :
		unsigned int width;			//window width
		unsigned int height;		//window height

		CameraArcball camera;		//Camera (view and projection wrapper)
		glm::mat4 model;			//Model matrix : local coordinates -> world coordinates

		GLuint programID;			//Id shader program

		GLuint vertexPositionID;	//Id shader attribute
		GLuint vertexBufferObject;	//Id buffer object

        GLuint vertexNormalID;
        GLuint normalBufferObject;

        GLuint indexBufferObject;

		std::vector< glm::vec3 > vertices;		//data to display
};
#endif
